@@ -408,6 +408,11 @@ class TestEval(TestCase):
         self.interp('nx = 1')
         self.interp('nx1 = 1')
 
+        if PY3:
+            # use \u escape b/c python 2 complains about file encoding
+            self.interp('\u03bb = 1')
+            self.interp('\u03bb1 = 1')
+
     def test_syntaxerrors_1(self):
         """assignment syntax errors test"""
         for expr in ('class = 1', 'for = 1', 'if = 1', 'raise = 1',
@@ -815,10 +820,18 @@ class TestEval(TestCase):
         self.check_error(None)
         self.interp("10**10001")
         self.check_error('RuntimeError')
+        self.interp("10**array([10000, 10000, 10000])")
+        self.check_error(None)
+        self.interp("10**array([10000, 10000, 10001])")
+        self.check_error('RuntimeError')
         self.interp("1<<1000")
         self.check_error(None)
         self.interp("1<<1001")
         self.check_error('RuntimeError')
+        self.interp("1<<array([1000, 1000, 1000])")
+        self.check_error(None)
+        self.interp("1<<array([1000, 1000, 1001])")
+        self.check_error('RuntimeError')
 
     def test_safe_open(self):
         self.interp('open("foo1", "wb")')
